pub enum BatchDetectSyntaxError {
BatchSizeLimitExceeded(String),
InternalServer(String),
InvalidRequest(String),
TextSizeLimitExceeded(String),
UnsupportedLanguage(String),
}Expand description
Errors returned by BatchDetectSyntax
Variants
BatchSizeLimitExceeded(String)
The number of documents in the request exceeds the limit of 25. Try your request again with fewer documents.
InternalServer(String)
An internal server error occurred. Retry your request.
InvalidRequest(String)
The request is invalid.
TextSizeLimitExceeded(String)
The size of the input text exceeds the limit. Use a smaller document.
UnsupportedLanguage(String)
Amazon Comprehend can't process the language of the input text. For all custom entity recognition APIs (such as CreateEntityRecognizer), only English is accepted. For most other APIs, such as those for Custom Classification, Amazon Comprehend accepts text in all supported languages. For a list of supported languages, see supported-languages.
Implementations
Sourceimpl BatchDetectSyntaxError
impl BatchDetectSyntaxError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<BatchDetectSyntaxError>